summaryrefslogtreecommitdiff
path: root/noncore/settings/networksettings2/opietooth2/OTGateway.cpp
Side-by-side diff
Diffstat (limited to 'noncore/settings/networksettings2/opietooth2/OTGateway.cpp') (more/less context) (ignore whitespace changes)
-rw-r--r--noncore/settings/networksettings2/opietooth2/OTGateway.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/noncore/settings/networksettings2/opietooth2/OTGateway.cpp b/noncore/settings/networksettings2/opietooth2/OTGateway.cpp
index 1b61a2e..7fc8719 100644
--- a/noncore/settings/networksettings2/opietooth2/OTGateway.cpp
+++ b/noncore/settings/networksettings2/opietooth2/OTGateway.cpp
@@ -64,5 +64,5 @@ OTGateway::OTGateway( void ) : QObject( 0, "OTGateway" ),
// iterate over drivers and find active connections
// adding/updating peers
- loadActiveConnections();
+ loadActiveNetworkSetups();
@@ -377,4 +377,4 @@ const char * OTGateway::deviceTypeToName( int cls ) {
-PANConnectionVector OTGateway::getPANConnections( void ) {
- PANConnectionVector V;
+PANNetworkSetupVector OTGateway::getPANNetworkSetups( void ) {
+ PANNetworkSetupVector V;
@@ -394,3 +394,3 @@ PANConnectionVector OTGateway::getPANConnections( void ) {
if (ioctl(ctl, BNEPGETCONNLIST, &req)) {
- odebug << "Failed to get connection list" << oendl;
+ odebug << "Failed to get NetworkSetup list" << oendl;
::close( ctl );
@@ -403,3 +403,3 @@ PANConnectionVector OTGateway::getPANConnections( void ) {
// we are the client
- V.insert( V.size()-1, new OTPANConnection(
+ V.insert( V.size()-1, new OTPANNetworkSetup(
ci[i].device,
@@ -512,3 +512,3 @@ bool OTGateway::removeLinkKey( unsigned int Index ) {
#define MAXCONNECTIONS 10
-void OTGateway::loadActiveConnections( void ) {
+void OTGateway::loadActiveNetworkSetups( void ) {
@@ -534,3 +534,3 @@ void OTGateway::loadActiveConnections( void ) {
- // driver is up -> check connections
+ // driver is up -> check NetworkSetups
cl->dev_id = AllDrivers[i]->devId();
@@ -540,3 +540,3 @@ void OTGateway::loadActiveConnections( void ) {
if (ioctl( getSocket(), HCIGETCONNLIST, (void *) cl)) {
- emit error( tr("Can't get connection list") );
+ emit error( tr("Can't get NetworkSetup list") );
break;
@@ -755,3 +755,3 @@ int OTGateway::releaseRFCommDevice( int devnr ) {
if( dr->id == devnr ) {
- // still in connection list
+ // still in NetworkSetup list
struct rfcomm_dev_req req;
@@ -64,5 +64,5 @@ OTGateway::OTGateway( void ) : QObject( 0, "OTGateway" ),
- // iterate over drivers and find active connections
+ // iterate over drivers and find active NetworkSetups
// adding/updating peers